@@ -1,21 +1,34 @@
 package MooseX::Constructor::AllErrors;
+our $VERSION = '0.001';
+
+
+use strict;
+use warnings;
 
 use Moose ();
 use Moose::Exporter;
+use Moose::Util::MetaRole;
+use MooseX::Constructor::AllErrors::Meta::Class;
+use MooseX::Constructor::AllErrors::Meta::Attribute;
 
-use MooseX::Constructor::AllErrors::Error;
-use MooseX::Constructor::AllErrors::Error::Constructor;
-use MooseX::Constructor::AllErrors::Error::Required;
-use MooseX::Constructor::AllErrors::Error::TypeConstraint;
+Moose::Exporter->setup_import_methods(also => 'Moose');
 
-Moose::Exporter->setup_import_methods(
-    base_class_roles => [ 'MooseX::Constructor::AllErrors::Role::Object' ],
-    class_metaroles => {
-        ($Moose::VERSION < 1.9900
-            ? (constructor => ['MooseX::Constructor::AllErrors::Role::Meta::Method::Constructor'])
-            : (class       => ['MooseX::Constructor::AllErrors::Role::Meta::Class'])),
-    },
-);
+sub init_meta {
+  shift;
+  my %options = @_;
+
+  Moose->init_meta(%options);
+
+  Moose::Util::MetaRole::apply_metaclass_roles(
+    for_class => $options{for_class},
+    metaclass_roles => [
+      'MooseX::Constructor::AllErrors::Meta::Class',
+    ],
+    attribute_metaclass_roles => [
+      'MooseX::Constructor::AllErrors::Meta::Attribute',
+    ],
+  );
+}
 
 1;
 
@@ -25,6 +38,10 @@ __END__
 
 MooseX::Constructor::AllErrors - capture all constructor errors
 
+=head1 VERSION
+
+version 0.001
+
 =head1 SYNOPSIS
 
   package MyClass;
@@ -35,7 +52,7 @@ MooseX::Constructor::AllErrors - capture all constructor errors
 
   ...
 
-  eval { MyClass->new(bar => "hello") };
+  eval { MyClass->new };
   # $@->errors has two errors, not just the missing required attribute
 
 =head1 DESCRIPTION
@@ -47,6 +64,12 @@ If there are errors, C<$@> will contain a
 L<MooseX::Constructor::AllErrors::Error::Constructor> object.  See its
 documentation for possible error types.
 
+=begin Pod::Coverage
+
+init_meta
+
+=end Pod::Coverage
+
 =head1 SEE ALSO
 
 L<Moose>
@@ -61,4 +84,4 @@ This software is copyright (c) 2009 by Hans Dieter Pearcey. This is free
 software; you can redistribute it and/or modify it under the same terms as perl
 itself. 
 
-=cut
+=cut
\ No newline at end of file
